@@ -1,6 +1,4 @@
-pub mod utils {
-    mod macros;
-}
+pub mod cli;
 
 pub mod input {
     mod formatter;
@@ -13,9 +11,7 @@ pub mod input {
 
 pub mod errors {
     mod format;
-    mod sort;
     mod source;
     pub use self::format::*;
-    pub use self::sort::*;
     pub use self::source::*;
 }
